BaseResponse class abstract

Abtract response adapter

Constructors

BaseResponse()

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, List<String>>
Headers for the response.
no setter
requestUri Uri
request URI
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
Response status code
no setter

Methods

isAttachment() bool
Checks if Content-Disposition header of the response is attachment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited